Learn R Programming

xtranat (version 0.1.0)

cbet: Computes Counting Betweenness

Description

Counting Betweenness implemented as in DePaolis et al(2022)

Usage

cbet(A)

Value

The vector containing the values of Counting Betweenness of the network..

Arguments

A

The adjacency matrix of the network to be analyzed. It must be square.

Examples

Run this code
cbet(exmpl_matrix)

Run the code above in your browser using DataLab