Learn R Programming

xtranat (version 0.1.0)

cbet_norm: Computes Counting Betweenness in normalized format

Description

A normalized version of Counting Betweenness implemented as in DePaolis et al(2022)

Usage

cbet_norm(A)

Value

The vector containing the normalized values (between 0 and 1) of Counting Betweenness of the network.

Arguments

A

The adjacency matrix of the network to be analyzed.It must be square.

Examples

Run this code
cbet_norm(exmpl_matrix)

Run the code above in your browser using DataLab