Learn R Programming

xtranat (version 0.1.0)

rwc_norm: Computes Random Walk Centrality in normalized format

Description

A normalized version of Random Walk Centrality implemented as in DePaolis et al(2022)

Usage

rwc_norm(A)

Value

The vector containing the normalized values (between 0 and 1) of Random Walk Centrality of the network.

Arguments

A

The adjacency matrix of the network to be analyzed.It must be square.

Examples

Run this code
rwc_norm(exmpl_matrix)

Run the code above in your browser using DataLab