powered by
Counting Betweenness implemented as in DePaolis et al(2022)
cbet(A)
The vector containing the values of Counting Betweenness of the network..
The adjacency matrix of the network to be analyzed. It must be square.
cbet(exmpl_matrix)
Run the code above in your browser using DataLab