powered by
A normalized version of Counting Betweenness implemented as in DePaolis et al(2022)
cbet_norm(A)
The vector containing the normalized values (between 0 and 1) of Counting Betweenness of the network.
The adjacency matrix of the network to be analyzed.It must be square.
cbet_norm(exmpl_matrix)
Run the code above in your browser using DataLab