powered by
A normalized version of Random Walk Centrality implemented as in DePaolis et al(2022)
rwc_norm(A)
The vector containing the normalized values (between 0 and 1) of Random Walk Centrality of the network.
The adjacency matrix of the network to be analyzed.It must be square.
rwc_norm(exmpl_matrix)
Run the code above in your browser using DataLab